@@ -40,7 +40,9 @@ LanguagePreferences.localLanguageName["hu"] = "Magyar";
 LanguagePreferences.localLanguageName["hr"] = "Hrvatski";
 LanguagePreferences.localLanguageName["it"] = "Italiano";
 LanguagePreferences.localLanguageName["ja"] = "日本語";
+LanguagePreferences.localLanguageName["ko"] = "한국어";
 LanguagePreferences.localLanguageName["lt"] = "Lietuvių kalba";
+LanguagePreferences.localLanguageName["nb"] = "Norsk";
 LanguagePreferences.localLanguageName["nl"] = "Nederlands";
 LanguagePreferences.localLanguageName["pl"] = "Polski";
 LanguagePreferences.localLanguageName["pt"] = "Português";
@@ -50,9 +52,10 @@ LanguagePreferences.localLanguageName["sk"] = "Slovenčina";
 LanguagePreferences.localLanguageName["sl"] = "Slovenščina";
 LanguagePreferences.localLanguageName["sv"] = "Svenska";
 LanguagePreferences.localLanguageName["tr"] = "Türkçe";
+LanguagePreferences.localLanguageName["uk"] = "Українська";
 LanguagePreferences.localLanguageName["zh_TW"] = "繁體中文";
 LanguagePreferences.localLanguageName["zh"] = "简体中文";
-LanguagePreferences.localLanguageName["zh_ZN"] = "简体中文";
+LanguagePreferences.localLanguageName["zh_CN"] = "简体中文";
 
 LanguagePreferences.getPreferencesCategory = function() {
     return [qsTr("Language Settings"), qsTr("Language")];
@@ -126,15 +129,6 @@ LanguagePreferences.getLanguages = function(dirName) {
     
     var dir = new QDir(dirName);
     var sortFlags = makeQDirSortFlags(QDir.NoSort);
-    /*
-    var dirFilter = new QDir.Filters(QDir.NoDotAndDotDot, QDir.Readable,
-            QDir.Dirs);
-    var dirs = dir.entryInfoList(dirFilter, sortFlags);
-    
-    for (var i = 0; i < dirs.length; ++i) {
-        codes = codes.concat(LanguagePreferences.getLanguages(dirs[i].absoluteFilePath()));
-    }
-    */
     
     var fileFilter = makeQDirFilters(QDir.Readable, QDir.Files);
     var files = dir.entryInfoList(["*.qm"], fileFilter, sortFlags);
