@@ -3,8 +3,7 @@ function init(basePath) {
     action.setRequiresDocument(true);
     action.setForceGlobal(true);
     action.setScriptFile(basePath + "/PrintCurrentView.js");
-    action.setIcon(basePath + "/PrintCurrentView.svg");
-    action.setDefaultShortcut(new QKeySequence(Qt.ControlModifier + Qt.AltModifier + Qt.Key_P));
+    action.setDefaultShortcut(new QKeySequence("Ctrl+Alt+P"));
     action.setDefaultCommands(["printview"]);
     action.setStatusTip(qsTranslate("PrintCurrentView", "Print current view"));
     action.setGroupSortOrder(1600);
