@@ -85,7 +85,6 @@ Projection.getCadToolBarPanel = function() {
         action.setScriptFile(Projection.includeBasePath + "/Projection.js");
         action.objectName = actionName;
         action.setRequiresDocument(true);
-        action.setIcon(Projection.includeBasePath + "/Projection.svg");
         //action.setStatusTip(qsTr("Show projection tools"));
         action.setDefaultShortcut(new QKeySequence("w,j"));
         action.setNoState();
@@ -243,33 +242,57 @@ Projection.prototype.transform = function(entity, k, op, preview, flags, rec) {
         this.preTransform(entity);
     }
 
+    var explode = false;
+
     if (this.retainTexts && isTextBasedEntity(entity)) {
-        // don't explode text, only project position:
-        var e = entity.clone();
-        e.setSelected(false);
-        var p = e.getAlignmentPoint();
-        //qDebug("p before:", p);
-        //qDebug("ap:", e.getAlignmentPoint());
-        this.project(p);
-        //qDebug("p after:", p);
-        //e.setPosition(p);
-        e.setAlignmentPoint(p);
-        flags = flags | RAddObjectsOperation.UseAttributes;
-        op.addObject(e, flags);
-        return;
+        if (isAttributeEntity(entity)) {
+            explode = true;
+        }
+        else {
+            // don't explode text, only project position:
+            var e = entity.clone();
+            e.setSelected(false);
+            var p = e.getAlignmentPoint();
+            var ph = p.operator_add(new RVector(0,e.getTextHeight()));
+            //qDebug("p before:", p);
+            //qDebug("ph before:", ph);
+            //qDebug("ap:", e.getAlignmentPoint());
+            this.project(p);
+            this.project(ph);
+
+            // project height:
+            //qDebug("p after:", p);
+            //qDebug("ph after:", ph);
+            //e.setPosition(p);
+
+            e.setAlignmentPoint(p);
+            e.setTextHeight(p.getDistanceTo(ph));
+
+            flags = flags | RAddObjectsOperation.UseAttributes;
+            op.addObject(e, flags);
+            return;
+        }
     }
 
     // explode block reference to keep attributes (colors, etc.):
     if (isBlockReferenceEntity(entity)) {
-        var explodedEntities = Explode.explodeEntity(entity);
-        for (i=0; i<explodedEntities.length; i++) {
-            var explodedEntity = explodedEntities[i];
+        explode = true;
+    }
 
-            if (isEntity(explodedEntity)) {
-                this.transform(explodedEntity, k, op, preview, flags, true);
-            }
-            else {
-                qWarning("shape in exploded block");
+    if (explode) {
+        // explode attributes to texts
+        // explode block reference
+        var explodedEntities = Explode.explodeEntity(entity);
+        if (!isNull(explodedEntities)) {
+            for (i=0; i<explodedEntities.length; i++) {
+                var explodedEntity = explodedEntities[i];
+
+                if (isEntity(explodedEntity)) {
+                    this.transform(explodedEntity, k, op, preview, flags, true);
+                }
+                else {
+                    qWarning("shape in exploded block");
+                }
             }
         }
         return;
@@ -309,7 +332,7 @@ Projection.prototype.addTransformedShapes = function(entity, shapes, op, preview
         hd.newLoop();
 
         for (i=0; i<shapes.length; i++) {
-            s = this.projectShape(shapes[i].data(), preview);
+            s = this.projectShape(getPtr(shapes[i]), preview);
             for (n=0; n<s.length; n++) {
                 if (isNull(s[n])) {
                     debugger;
@@ -319,7 +342,12 @@ Projection.prototype.addTransformedShapes = function(entity, shapes, op, preview
                     s[n].simplify(0.001);
                 }
 
-                hd.addBoundary(s[n], true);
+                if (RSettings.getQtVersion() >= 0x060000) {
+                    hd.addBoundary(s[n].clone(), true);
+                }
+                else {
+                    hd.addBoundary(s[n], true);
+                }
             }
         }
 
@@ -344,7 +372,7 @@ Projection.prototype.addTransformedShapes = function(entity, shapes, op, preview
             continue;
         }
 
-        s = this.projectShape(shapes[i].data(), preview);
+        s = this.projectShape(getPtr(shapes[i]), preview);
         for (n=0; n<s.length; n++) {
             if (isNull(s[n])) {
                 debugger;
@@ -536,6 +564,8 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
         // create polyline from ellipse:
         var ple = ShapeAlgorithms.approximateEllipse(shape, 16);
         return this.projectShape(ple, preview, trim);
+
+        // TODO: project ellipse bounding box and inscribe new ellipse (?)
     }
 
     if (isTriangleShape(shape)) {
@@ -561,7 +591,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
 //        var shapes = shape.getExploded(segments);
 //        var pls = new RPolyline();
 //        for (i=0; i<shapes.length; i++) {
-//            s = shapes[i].data();
+//            s = getPtr(shapes[i]);
 //            pls.appendShape(s);
 //        }
         ret = this.projectShape(pls, preview, trim);
@@ -584,7 +614,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
 
         // project each segment individually:
         for (i=0; i<segmentCount; i++) {
-            s = shape.getSegmentAt(i).data();
+            s = getPtr(shape.getSegmentAt(i));
 
             s = this.projectShape(s, preview, trim, true);
 
@@ -592,7 +622,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
             for (k=0; k<s.length; k++) {
                 var seg = s[k];
                 if (isFunction(seg.data)) {
-                    seg = seg.data();
+                    seg = getPtr(seg);
                 }
 
                 var gotGap = pl.countVertices()>0 &&
@@ -640,6 +670,40 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
             ret.push(pl);
         }
 
+        // set global width if polyline has uniform global semgent width:
+        var gotGlobalWidth = false;
+        var startWidths = shape.getStartWidths();
+        var endWidths = shape.getEndWidths();
+        if (startWidths.length>0 && endWidths.length>0) {
+            if (startWidths[0]>RS.PointTolerance) {
+                startWidths.sortNumerical();
+                endWidths.sortNumerical();
+                if (RMath.fuzzyCompare(startWidths[0], startWidths[startWidths.length-1]) &&
+                    RMath.fuzzyCompare(endWidths[0], endWidths[endWidths.length-1]) &&
+                    RMath.fuzzyCompare(startWidths[0], endWidths[0])) {
+
+                    // got global polyline width:
+                    gotGlobalWidth = true;
+                    for (i=0; i<ret.length; i++) {
+                        if (isPolylineShape(ret[i])) {
+                            ret[i].setGlobalWidth(startWidths[0]);
+                        }
+                    }
+                }
+            }
+        }
+
+        // set pl segment widths if there's no segmentation and the number of segments match:
+        if (ret.length===1 && isPolylineShape(ret[0])) {
+            if (!gotGlobalWidth && !this.segmentation && shape.countSegments()===ret[0].countSegments()) {
+                for (i=0; i<shape.countVertices(); i++) {
+                    ret[0].setStartWidthAt(i, shape.getStartWidthAt(i));
+                    ret[0].setEndWidthAt(i, shape.getEndWidthAt(i));
+                }
+            }
+        }
+
+
         return ret;
     }
 
